@@ -1,4 +1,4 @@
-// $Id: chcontext.c,v 1.8 2004/02/02 19:06:19 ensc Exp $
+// $Id: chcontext.c,v 1.9 2004/02/05 03:41:58 ensc Exp $
 
 // Copyright (C) 2003,2004 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 // based on chcontext.cc by Jacques Gelinas
@@ -223,8 +223,8 @@ setHostname(char const *name)
 {
   if (name == NULL) return;
   
-  if (vc_set_vhi_name(VC_SAMECTX, vcVHI_NODENAME, name, strlen(name))==-1) {
-    perror("setHostname()");
+  if (sethostname(name, strlen(name))==-1) {
+    perror("sethostname()");
     exit(255);
   }
   if (!global_args->do_silent) {
@@ -239,8 +239,8 @@ setDomainname(char const *name)
 {
   if (name == NULL) return;
   
-  if (vc_set_vhi_name(VC_SAMECTX, vcVHI_DOMAINNAME, name, strlen(name))==-1) {
-    perror("setDomainname()");
+  if (setdomainname(name, strlen(name))==-1) {
+    perror("setdomainname()");
     exit(255);
   }
   if (!global_args->do_silent) {
